%define major		7
%define libname		%mklibname netcdff %{major}
%define develname	%mklibname netcdff -d

Summary:	Fortran libraries for the Unidata network Common Data Form (netCDF)
Name:		netcdf-fortran
Version:	4.5.3
Release:	%mkrel 3
Group:		Development/Other
License:	NetCDF
URL:		https://www.unidata.ucar.edu/software/netcdf/
Source0:	https://downloads.unidata.ucar.edu/netcdf-fortran/%{version}/%{name}-%{version}.tar.gz
BuildRequires:	gcc-gfortran
BuildRequires:	pkgconfig(netcdf)

%description
NetCDF (network Common Data Form) is an interface for array-oriented data
access and a freely-distributed collection of software libraries for C,
Fortran, C++, and perl that provides an implementation of the interface.
The netCDF library also defines a machine-independent format for representing
scientific data. Together, the interface, library, and format support the
creation, access, and sharing of scientific data. The netCDF software was
developed at the Unidata Program Center in Boulder, Colorado.

NetCDF data is:

   o Self-Describing. A netCDF file includes information about the data it
     contains.

   o Network-transparent. A netCDF file is represented in a form that can be
     accessed by computers with different ways of storing integers, characters,
     and floating-point numbers.

   o Direct-access. A small subset of a large dataset may be accessed
     efficiently, without first reading through all the preceding data.

   o Appendable. Data can be appended to a netCDF dataset along one dimension
     without copying the dataset or redefining its structure. The structure of
     a netCDF dataset can be changed, though this sometimes causes the dataset
     to be copied.

   o Shareable. One writer and multiple readers may simultaneously access the
     same netCDF file.


%package -n	%{libname}
Summary:	Fortran libraries for netcdf-4
Group:		System/Libraries
Obsoletes:	%{_lib}netcdf_fortran5 < %{version}

%description -n	%{libname}
This package contains the netCDF-4 fortran libraries.

%package -n	%{develname}
Summary:	Development files for netcdf-4
Group:		Development/Other
Requires:	%{libname} = %{version}-%{release}
Provides:	lib%{name}-devel = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Conflicts:	%{_lib}netcdf-devel < 4.2.1.1
Conflicts:	netcdf < 4.2.1.1

%description -n %{develname}
This package contains the netCDF-4 header files, shared devel libs, and
man pages.

%prep
%setup -q

%build
export FCFLAGS="%{optflags}"
export FFLAGS="%{optflags}"
%configure --enable-shared --disable-static
%make_build

%check
#(eatdirt) prevent to be build
#make check

%install
%make_install

find %{buildroot} -name '*.la' -delete

%files -n %{libname}
%{_libdir}/libnetcdff.so.%{major}{,.*}
%{_libdir}/libnetcdff.settings

%files -n %{develname}
%{_bindir}/nf-config
%{_includedir}/*
%{_libdir}/libnetcdff.so
%{_libdir}/pkgconfig/*.pc
%{_mandir}/man3/*


%changelog
* Fri Jun 27 2025 umeabot <umeabot> 4.5.3-3.mga10
+ Revision: 2213906
- Mageia 10 Mass Rebuild

* Sat Apr 02 2022 umeabot <umeabot> 4.5.3-2.mga9
+ Revision: 1840490
- Mageia 9 Mass Rebuild

* Sat Dec 11 2021 eatdirt <eatdirt> 4.5.3-1.mga9
+ Revision: 1761452
- Upgrade to version 4.5.3

* Mon Oct 26 2020 akien <akien> 4.5.2-5.mga8
+ Revision: 1639580
- Rebuild against libnetcdf18

* Thu Oct 01 2020 pterjan <pterjan> 4.5.2-4.mga8
+ Revision: 1631526
- Rebuild for new netcdf on arm

* Thu Aug 20 2020 joequant <joequant> 4.5.2-3.mga8
+ Revision: 1616779
- fix fortran build
- fix build

* Fri Mar 20 2020 eatdirt <eatdirt> 4.5.2-2.mga8
+ Revision: 1558368
- Skip tests from now
+ daviddavid <daviddavid>
- new version: 4.5.2
- rebuild for new netcdf 4.7.3

* Sat Feb 15 2020 umeabot <umeabot> 4.4.4-4.mga8
+ Revision: 1526056
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Wed Apr 24 2019 daviddavid <daviddavid> 4.4.4-3.mga7
+ Revision: 1395198
- rebuild for new hdf5 1.10.5

* Sun Sep 23 2018 umeabot <umeabot> 4.4.4-2.mga7
+ Revision: 1299705
- Mageia 7 Mass Rebuild

* Wed Aug 01 2018 eatdirt <eatdirt> 4.4.4-1.mga7
+ Revision: 1246621
- Upgrade to version 4.4.4

* Mon Sep 11 2017 tv <tv> 4.4.2-4.mga7
+ Revision: 1152782
- rebuild for new libgfortran

* Tue Feb 16 2016 umeabot <umeabot> 4.4.2-3.mga6
+ Revision: 961730
- Mageia 6 Mass Rebuild

* Thu Aug 13 2015 fwang <fwang> 4.4.2-2.mga6
+ Revision: 864223
- cleanup requirements

* Thu Aug 13 2015 fwang <fwang> 4.4.2-1.mga6
+ Revision: 864218
- update libmajor
- 4.4.2

* Wed Oct 15 2014 umeabot <umeabot> 4.2-7.mga5
+ Revision: 749548
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 4.2-6.mga5
+ Revision: 682848
- Mageia 5 Mass Rebuild

* Fri Oct 18 2013 umeabot <umeabot> 4.2-5.mga4
+ Revision: 508293
- Mageia 4 Mass Rebuild
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Sep 19 2012 fwang <fwang> 4.2-3.mga3
+ Revision: 296188
- obsolete files

* Wed Sep 19 2012 fwang <fwang> 4.2-2.mga3
+ Revision: 296159
- bump rel

* Wed Sep 19 2012 fwang <fwang> 4.2-1.mga3
+ Revision: 296148
- update file list
- imported package netcdf-fortran

